#include "audiowidget.h"


AudioWidget::AudioWidget(QWidget *parent) :
    QWidget(parent)
  , m_layout(new QHBoxLayout())
{
    for (int i= 0; i < Settings::getInstance()->getLayersNumber(); i++ ) {
        AudioLayerWidget *alw = new AudioLayerWidget(this, i);
        m_layout->insertWidget(i, alw);
        connect(alw, SIGNAL(uiSliderChanged(int, Slider, int)), this, SIGNAL(uiSliderChanged(int, Slider, int)));
        connect(alw, SIGNAL(uiPlaybackChanged(int, Status)), this, SIGNAL(uiPlaybackChanged(int, Status)));
    }
    m_layout->setSpacing(0);
    m_layout->setContentsMargins(1, 1, 1, 1);
    setLayout(m_layout);
}

void AudioWidget::mediaLoaded(int layer, QString file, float duration)
{
    QLayoutItem * const item = m_layout->itemAt(layer);
    dynamic_cast<AudioLayerWidget *>(item->widget())->fileLoaded(file);
    dynamic_cast<AudioLayerWidget *>(item->widget())->durationChanged(duration);
}

void AudioWidget::volChanged(int layer, float vol) {
    QLayoutItem * const item = m_layout->itemAt(layer);
    dynamic_cast<AudioLayerWidget *>(item->widget())->setVol(vol);
}

void AudioWidget::panChanged(int layer, int pan) {
    QLayoutItem * const item = m_layout->itemAt(layer);
    dynamic_cast<AudioLayerWidget *>(item->widget())->setPan(pan);
}

void AudioWidget::pitchChanged(int layer, int pitch) {
    QLayoutItem * const item = m_layout->itemAt(layer);
    dynamic_cast<AudioLayerWidget *>(item->widget())->setPitch(pitch);
}

void AudioWidget::playbackChanged(int layer, Status status)
{
    QLayoutItem * const item = m_layout->itemAt(layer);
    dynamic_cast<AudioLayerWidget *>(item->widget())->setPlaybackStatus(status);
}

void AudioWidget::cursorChanged(int layer, float cursor)
{
    QLayoutItem * const item = m_layout->itemAt(layer);
    AudioLayerWidget *alw = dynamic_cast<AudioLayerWidget *>(item->widget());
    alw->refreshUi(cursor);
}
/*
void AudioWidget::uiSliderAction(int layer, Slider s, float value)
{
    emit uiSliderChanged(layer, s, value);
}

void AudioWidget::uiChangePlaybackStatus(int layer, Status s) {
    emit uiPlaybackChanged(layer, s);
}*/
